==> kendo-pivotgrid-vue-wrapper-2018.3.911.tgz: package/docs/excel-export.md <==
---
title: Excel Export
page_title: Excel Export - PivotGrid - Kendo UI for Vue
description: "Explore the Excel export options provided by the Kendo UI PivotGrid wrapper for Vue."
slug: excel_export_pivotgrid
position: 3
---

# Excel Export

The built-in export functionality of the PivotGrid allows you to easily export data to Excel.

## Basics

When using the PivotGrid component, it is often useful and important to export your data to MS Excel in order to make it accessible offline, share it with your colleagues, etc.

The Kendo PivotGrid Vue component provides client Excel export functionality (server-agnostic) which can be directly utilized to serve the purpose to share data in the aforementioned ways. You can trigger Excel export by invoking the [saveAsExcel](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid/methods/saveasexcel) method from the client API of the PivotGrid.

In order for the excel export to work, you would also need to add a reference to the jszip library on the page. You can do this by either using npm and assigning the global window.JSZip variable, or by adding the script from CDN:
```html-no-run
<script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/2.4.0/jszip.js"></script>
```

{% meta height:490 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-button @click="onClick" class="k-primary">Export</kendo-button>
    <kendo-pivotdatasource ref="pivotdatasource1"
                           transport-read-url="https://demos.telerik.com/olap/msmdpump.dll"
                           transport-connection-catalog="Adventure Works DW 2008R2"
                           transport-connection-cube="Adventure Works"
                           type="xmla"
                           schema-type="xmla"
                           :measures="measures">
          <kendo-pivot-column :name="'[Date].[Calendar]'" :expand="true"></kendo-pivot-column>
          <kendo-pivot-row :name="'[Product].[Product Line]'" :expand="true"></kendo-pivot-row>
    </kendo-pivotdatasource>
    <kendo-pivotgrid id="pivotgrid1"
                     ref="pivot1"
                     data-source-ref="pivotdatasource1"
                     :columnWidth="200"
                     :height="400"
                     :excel-file-name="'Kendo UI PivotGrid Export.xlsx'"
                     :excel-proxy-URL="'https://demos.telerik.com/kendo-ui/service/export'"
                     :excel-filterable="true">
    </kendo-pivotgrid>
</div>
<style>
    .hidden-on-narrow {
        display: inline-block;
        vertical-align: top;
    }
</style>
```
```js
Vue.use(ButtonsInstaller);
Vue.use(PivotGridInstaller);
Vue.use(DataSourceInstaller);

window.JSZip = JSZip;

new Vue({
    el: '#vueapp',
    data () {
        return {
            measures: ['[Measures].[Reseller Freight Cost]']
        }
    },
    methods: {
      onClick: function (ev) {
        var pivot = this.$refs.pivot1.kendoWidget()
        pivot.saveAsExcel()
      }
    }
})
```
{% endmeta %}

## Suggested Links

* [Kendo UI PivotGrid for jQuery](https://docs.telerik.com/kendo-ui/controls/data-management/pivotgrid/overview)
* [API Reference of the PivotGrid Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid)

==> kendo-pivotgrid-vue-wrapper-2019.1.115-dev.124.tgz: package/docs/excel-export.md <==
---
title: Excel Export
page_title: Excel Export - PivotGrid - Kendo UI for Vue
description: "Explore the Excel export options provided by the Kendo UI PivotGrid wrapper for Vue."
slug: excel_export_pivotgrid
position: 3
---

# Excel Export

The built-in export functionality of the PivotGrid allows you to share and distribute data in Excel.

## Basics

The PivotGrid enables you to export data to MS Excel and provides client Excel-export functionality which is server-agnostic and which can be directly utilized to share data offline. To trigger the export to Excel, invoke the [`saveAsExcel`](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid/methods/saveasexcel) method of the PivotGrid. In order for the Excel export to work, add a reference to the `jszip` library on the page by either using NPM and assigning the global `window.JSZip` variable or by adding the script from CDN with the <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/2.4.0/jszip.js"></script> code. 

{% meta height:490 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-button @click="onClick" class="k-primary">Export</kendo-button>
    <kendo-pivotdatasource ref="pivotdatasource1"
                           transport-read-url="https://demos.telerik.com/olap/msmdpump.dll"
                           transport-connection-catalog="Adventure Works DW 2008R2"
                           transport-connection-cube="Adventure Works"
                           type="xmla"
                           schema-type="xmla"
                           :measures="measures">
          <kendo-pivot-column :name="'[Date].[Calendar]'" :expand="true"></kendo-pivot-column>
          <kendo-pivot-row :name="'[Product].[Product Line]'" :expand="true"></kendo-pivot-row>
    </kendo-pivotdatasource>
    <kendo-pivotgrid id="pivotgrid1"
                     ref="pivot1"
                     data-source-ref="pivotdatasource1"
                     :columnWidth="200"
                     :height="400"
                     :excel-file-name="'Kendo UI PivotGrid Export.xlsx'"
                     :excel-proxy-URL="'https://demos.telerik.com/kendo-ui/service/export'"
                     :excel-filterable="true">
    </kendo-pivotgrid>
</div>
<style>
    .hidden-on-narrow {
        display: inline-block;
        vertical-align: top;
    }
</style>
```
```js
Vue.use(ButtonsInstaller);
Vue.use(PivotGridInstaller);
Vue.use(DataSourceInstaller);

window.JSZip = JSZip;

new Vue({
    el: '#vueapp',
    data () {
        return {
            measures: ['[Measures].[Reseller Freight Cost]']
        }
    },
    methods: {
      onClick: function (ev) {
        var pivot = this.$refs.pivot1.kendoWidget()
        pivot.saveAsExcel()
      }
    }
})
```
{% endmeta %}

## Suggested Links

* [Kendo UI PivotGrid for jQuery](https://docs.telerik.com/kendo-ui/controls/data-management/pivotgrid/overview)
* [API Reference of the PivotGrid Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid)
